def load():
    """name of dataset: fish
    no of variables: 20
    no of observations: 97

    +----------+----------------------------------------------+
    | variable | label                                        |
    +----------+----------------------------------------------+
    | prca     | price for Asian buyers                       |
    | prcw     | price for white buyers                       |
    | qtya     | quantity sold to Asians                      |
    | qtyw     | quantity sold to whites                      |
    | mon      | =1 if Monday                                 |
    | tues     | =1 if Tuesday                                |
    | wed      | =1 if Wednesday                              |
    | thurs    | =1 if Thursday                               |
    | speed2   | min past 2 days wind speeds                  |
    | wave2    | avg max last 2 days wave height              |
    | speed3   | 3 day lagged max windspeed                   |
    | wave3    | avg max wave hghts of 3 & 4 day lagged hghts |
    | avgprc   | ((prca*qtya) + (prcw*qtyw))/(qtya + qtyw)    |
    | totqty   | qtya + qtyw                                  |
    | lavgprc  | log(avgprc)                                  |
    | ltotqty  | log(totqty)                                  |
    | t        | time trend                                   |
    | lavgp_1  | lavgprc[_n-1]                                |
    | gavgprc  | lavgprc - lavgp_1                            |
    | gavgp_1  | gavgprc[_n-1]                                |
    +----------+----------------------------------------------+

    K Graddy (1995), “Testing for Imperfect Competition at the Fulton Fish
    Market,” RAND Journal of Economics 26, 75-92. Professor Graddy's
    collaborator on a later paper, Professor Joshua Angrist at MIT, kindly
    provided me with these data."""

    import wooldridge
    return wooldridge.load(__file__, "fish.csv.bz2")


def wooldridge():
    import wooldridge
    print(wooldridge.dataset_list)