def load():
    """name of dataset: lowbrth
    no of variables: 36
    no of observations: 100

    +----------+-------------------------------+
    | variable | label                         |
    +----------+-------------------------------+
    | year     | 1987 or 1990                  |
    | lowbrth  | perc births low weight        |
    | infmort  | infant mortality rate         |
    | afdcprt  | # participants in AFDC, 1000s |
    | popul    | population, 1000s             |
    | pcinc    | per capita income             |
    | physic   | # physicians, 1000s           |
    | afdcprc  | percent of pop in AFDC        |
    | d90      | =1 if year == 1990            |
    | lpcinc   | log of pcinc                  |
    | cafdcprc | change in afdcprc             |
    | clpcinc  | change in lpcinc              |
    | lphysic  | log of physic                 |
    | clphysic | change in lphysic             |
    | clowbrth | change in lowbrth             |
    | cinfmort | change in infmort             |
    | afdcpay  | avg monthly AFDC payment      |
    | afdcinc  | afdcpay as % pcinc            |
    | lafdcpay | log of afdcpay                |
    | clafdcpy | change in lafdcpay            |
    | cafdcinc | change in afdcinc             |
    | stateabb | state postal code             |
    | state    | name of state                 |
    | beds     | # hospital beds, 1000s        |
    | bedspc   | beds per capita               |
    | lbedspc  | log(bedspc)                   |
    | clbedspc | change in lbedspc             |
    | povrate  | % people below poverty line   |
    | cpovrate | change in povrate             |
    | afdcpsq  | afdcper^2                     |
    | cafdcpsq | change in afdcpsq             |
    | physicpc | physicians per capita         |
    | lphypc   | log(physicpc)                 |
    | clphypc  | change in lphypc              |
    | lpopul   | log(popul)                    |
    | clpopul  | change in lpopul              |
    +----------+-------------------------------+

    Source: Statistical Abstract of the United States, 1990, 1993, and
    1994."""

    import wooldridge
    return wooldridge.load(__file__, "lowbrth.csv.bz2")


def wooldridge():
    import wooldridge
    print(wooldridge.dataset_list)